@@ -33,9 +33,9 @@ def jj(source, dest, data):
     return output
 
 
-def docker_build_image():
-    os.system(f"cd {CURDIR + '/../../../docker_images'}/docker_tango_python && docker build --tag tango_python_tue .")
-    pass
+# def docker_build_image(tag='tango_python_tue'):
+#     os.system(f"cd {CURDIR + '/../../../docker_images'}/docker_tango_python && docker build --tag {tag} .")
+#     pass
 
 def jj_handout(source, dest, data):
     out = jj(source, dest, data)
@@ -78,7 +78,7 @@ def run_relative(file, base):
 def deploy_assignment(base_name, INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT_BASE, STUDENT_GRADE_FILE,
                       output_tar=None,
                       COURSES_BASE=None,
-                      autograde_image='tango_python_tue'):
+                      autograde_image_tag='tango_python_tue'):
 
     assert os.path.isfile(INSTRUCTOR_GRADE_FILE)
     assert os.path.isfile(STUDENT_GRADE_FILE)
@@ -149,7 +149,7 @@ def deploy_assignment(base_name, INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT
             # 'nice_name': base_name + "please",
             'display_name': paths2report(INSTRUCTOR_BASE, INSTRUCTOR_REPORT_FILE).title,
             'handin_filename': handin_filename,
-            'autograde_image': autograde_image,
+            'autograde_image': autograde_image_tag,
             'src_files_to_handout': ['driver_python.py', 'student_sources.zip', handin_filename, os.path.basename(docker_helpers.__file__),
                                      os.path.basename(INSTRUCTOR_GRADE_FILE)], # Remove tname later; it is the upload.
             'instructor_grade_file': os.path.basename(INSTRUCTOR_GRADE_FILE),
@@ -210,23 +210,19 @@ def format_autolab_json(data, indent=None):
     }
     totals = {}
     for n, qs in data['details'].items():
-        print(n)
+        # print(n)
         title = qs['title']
         rs = {}
         for item, val in qs['items'].items():
-            print(item, val)
+            # print(item, val)
             item_name = item[1]
             pass_ = val['status'] == 'pass'
-
             d = {'passed': pass_}
             if not pass_:
-                # d['hint'] = val['stderr']
-                d['hint'] = "<br>".join( val['stderr'].strip().splitlines() )
-
-
+                # Unfortunately, html is escaped in template, so linebreaks do not work.
+                d['hint'] = val['stderr']
+                # d['hint'] = "<br>".join( val['stderr'].strip().splitlines() )
             rs[item_name] = d
-
-
         totals[title] = qs['obtained']
         stages.append(title)
         pres[title] = rs
@@ -249,12 +245,12 @@ def format_autolab_json(data, indent=None):
     #     'scores': 234,
     #       'pass': True
     # }
-    if indent is not None:
-        s = json.dumps(pres, indent=2)
+
+    if indent is not None: # for debug.
+        json_out = json.dumps(pres, indent=2)
     else:
-        s = json.dumps(pres)
-    print(s)
-    # totals
+        json_out = json.dumps(pres)
+    print(json_out)
     scores = {"scores": {'Unitgrade score': data['total'][0] }} #, 'scoreboard': [data['total'][0]] }
     print( json.dumps(scores) )
 
